@@ -1,15 +1,16 @@
 package Bitcoin::Crypto::Helpers;
 
-our $VERSION = "1.000_01";
+our $VERSION = "1.002_01";
 
 use v5.10;
+use strict;
 use warnings;
 use Exporter qw(import);
 use Crypt::Digest::RIPEMD160 qw(ripemd160);
 use Crypt::Digest::SHA256 qw(sha256);
 use List::Util qw(max);
 use Crypt::PK::ECC;
-use Math::BigInt 1.999808 try => 'LTM,GMP';
+use Math::BigInt 1.999808 try => 'GMP,LTM';
 
 use Bitcoin::Crypto::Config;
 use Bitcoin::Crypto::Exception;
