@@ -1,8 +1,9 @@
 package Bitcoin::Crypto::Role::Network;
 
-our $VERSION = "1.000_01";
+our $VERSION = "1.002_01";
 
 use v5.10;
+use strict;
 use warnings;
 use Types::Standard qw(InstanceOf Str);
 use Scalar::Util qw(blessed);
@@ -19,7 +20,14 @@ has "network" => (
 		return Bitcoin::Crypto::Network->get;
 	},
 	coerce => 1,
-	writer => "set_network"
+	writer => "_set_network"
 );
 
+sub set_network
+{
+	my ($self, $network) = @_;
+	$self->_set_network($network);
+	return $self;
+}
+
 1;
