@@ -1,14 +1,15 @@
 package Bitcoin::Crypto::Types;
 
-our $VERSION = "1.000_01";
+our $VERSION = "1.002_01";
 
 use v5.10;
+use strict;
 use warnings;
 use Type::Library -base;
 use Type::Coercion;
 use Types::Common::Numeric qw(assert_PositiveInt);
 use Types::Standard qw(Int InstanceOf);
-use Math::BigInt 1.999808 try => 'LTM,GMP';
+use Math::BigInt 1.999808 try => 'GMP,LTM';
 
 __PACKAGE__->add_type(
 	name => "IntMaxBits",
